==> qtjambi-uic-6.5.2-sources.jar: io/qt/uic/ui4/QtJambi_LibraryUtilities.java <==
package io.qt.uic.ui4;

import io.qt.*;
import static io.qt.QtUtilities.*;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 6;

    final static int qtMinorVersion = 5;

    final static int qtJambiPatch = 2;

    final static InternalAccess internal;

    static{
        try {
            initializePackage("io.qt.core");
            loadQtLibrary("DBus", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Network", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("OpenGL", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Positioning", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("PrintSupport", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Qml", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("QmlModels", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Quick", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("QuickWidgets", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Svg", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("VirtualKeyboard", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WaylandClient", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WaylandEglClientHwIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WebChannel", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WebEngineCore", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WebEngineWidgets", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WlShellIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.ProvideOnly, "windows");
            loadQtLibrary("Gui", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Widgets", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Xml", LibraryRequirementMode.Mandatory);
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.Optional, "windows");
            loadQtLibrary("OpenGL", LibraryRequirementMode.Mandatory);
            loadQtLibrary("OpenGLWidgets", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Designer", LibraryRequirementMode.Mandatory);
            loadQtJambiLibrary("UIC");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
        internal = internalAccess();
    }
    private static native InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws InstantiationError { throw new InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}

==> qtjambi-uic-6.5.6-sources.jar: io/qt/uic/ui4/QtJambi_LibraryUtilities.java <==
package io.qt.uic.ui4;

import io.qt.*;
import static io.qt.QtUtilities.*;

/**
 * @hidden
 */
final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 6;

    final static int qtMinorVersion = 5;

    final static int qtJambiPatch = 6;

    final static InternalAccess internal;

    static{
        try {
            initializePackage("io.qt.core");
            loadQtLibrary("DBus", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("EglFSDeviceIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("Network", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("OpenGL", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Pdf", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Positioning", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("PrintSupport", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Qml", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("QmlModels", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Quick", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("QuickWidgets", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("Svg", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WaylandClient", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WaylandEglClientHwIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("WebChannel", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WebEngineCore", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WebEngineWidgets", LibraryRequirementMode.ProvideOnly);
            loadQtLibrary("WlShellIntegration", LibraryRequirementMode.ProvideOnly, "linux");
            loadQtLibrary("XcbQpa", LibraryRequirementMode.ProvideOnly, "linux");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.ProvideOnly, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.ProvideOnly, "windows");
            loadQtLibrary("Gui", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Widgets", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Xml", LibraryRequirementMode.Mandatory);
            loadUtilityLibrary("libGLESv2", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("libEGL", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("opengl32sw", LibraryRequirementMode.Optional, "windows");
            loadUtilityLibrary("d3dcompiler_47", LibraryRequirementMode.Optional, "windows");
            loadQtLibrary("OpenGL", LibraryRequirementMode.Mandatory);
            loadQtLibrary("OpenGLWidgets", LibraryRequirementMode.Mandatory);
            loadQtLibrary("Designer", LibraryRequirementMode.Mandatory);
            loadQtJambiLibrary("UIC");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
        internal = internalAccess();
    }
    private static native InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws InstantiationError { throw new InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}
